@@ -1,6 +1,6 @@
 package Tapper::RawSQL::TestrunDB::testruns;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::RawSQL::TestrunDB::testruns::VERSION = '5.0.1';
+$Tapper::RawSQL::TestrunDB::testruns::VERSION = '5.0.2';
 use strict;
 use warnings;
 
@@ -299,7 +299,7 @@ sub continuous_list {
         'SQLite' => q#
             SELECT
                 t.id                                            AS testrun_id,
-                STRFTIME( '%Y-%m-%d %H:%M', r.created_at )      AS testrun_date,
+                STRFTIME( '%Y-%m-%d %H:%M', t.created_at )      AS testrun_date,
                 ts.status,
                 t.topic_name,
                 q.name                                          AS queue_name,
